import { useState, useEffect } from "react";
import Taro from "@tarojs/taro";
import { useSelector } from "react-redux";
import withLayout from "@/layout";
import { ScrollView, Input, Image, Block, Textarea } from "@tarojs/components";
import { getImgURL } from "@/utils/image";
import { fetch, uploadFiles } from "@/utils/request";
import { UPDATE_USER_INFO, ROLE_CODE } from "@/constants/user";
import { API_EDIT_AGENT, API_UPDATE_PHOTO } from "@/constants/api";
import store from "@/store";
import { isEmpty } from "@/utils/tools";
import "@/assets/css/iconfont.css";
import "./index.scss";

export default withLayout((props) => {
  const { columns, params, getList = () => {} } = props;

  const [list, setList] = useState([]);
  const [IsPull, setPull] = useState(false);

  const [pageNumber, setPageNumber] = useState(1);
  const [HasNextPage, setHasNextPage] = useState(true);

  useEffect(() => {
    if (pageNumber) {
      GetPageList();
    }
  }, [pageNumber]);

  const GetPageList = () => {
    setHasNextPage(false);
    getList({ ...params, pageNumber, pageSize: 10 }).then((res) => {
      setList(
        pageNumber === 1 ? res.records || [] : list.concat(res.records || [])
      );
      setHasNextPage(res.current < res.pages);
      setPull(false);
    });
  };

  const PageLoadMore = () => {
    // 页面上拉加载更多
    if (HasNextPage) {
      setPageNumber(pageNumber + 1);
    }
  };

  useEffect(() => {
    // 下拉刷新触发
    if (IsPull) {
      if (pageNumber === 1) {
        GetPageList();
      } else {
        setPageNumber(1);
      }
    }
  }, [IsPull]);

  return (
    <view className="component rankingListList">
      <view className="list-header">
        {columns?.map((x, index) => (
          <view key={index} style={{ width: x.width, textAlign: "center" }}>
            {x.title}
          </view>
        ))}
      </view>
      <ScrollView
        scroll-y
        refresher-triggered={IsPull}
        onscrolltolower={PageLoadMore}
        refresher-background="#fff"
      >
        <view className="list-tbody">
          {list?.map((item, index) => {
            return (
              <view className="list-tbody-row" key={index}>
                {columns?.map((x, index) => (
                  <view
                    key={x.key}
                    style={{ width: x.width, textAlign: "center" }}
                  >
                    
                    {(x?.render && x?.render(item,index)) ||
                      (!isEmpty(item[x.dataIndex]) ? item[x.dataIndex] : 0)}
                  </view>
                ))}
              </view>
            );
          })}
        </view>

        <view className="PageBottom">
          <text>已经到底了~</text>
        </view>
      </ScrollView>
    </view>
  );
});
