import { useState, useEffect } from "react";
import Taro from "@tarojs/taro";
import { useSelector } from "react-redux";
import withLayout from "@/layout";
import { ScrollView, Input, Image, Block, Textarea } from "@tarojs/components";
import { getImgURL } from "@/utils/image";
import { fetch, uploadFiles } from "@/utils/request";
import { UPDATE_USER_INFO, ROLE_CODE } from "@/constants/user";
import { API_BIND_BROKER, API_UPDATE_PHOTO } from "@/constants/api";
import store from "@/store";
import CardItem from "../components/CardItem";
import AddBankCard from "./AddBankCard";
import { querybkBankCard } from "@/services/broker";
import "@/assets/css/iconfont.css";
import "./index.scss";

export default withLayout((props) => {
  const { dispatch } = store;
  const {router} = props
  const recommendAgent =  router?.params?.recommendAgent
 console.log(recommendAgent,'==')

  const user = useSelector((state) => state.user);
  const [UserInfo, setUserInfo] = useState({});
  const [UserRole, setUserRole] = useState(null); // 1-普通用户 2-经纪人 3-置业顾问 4-驻场管理 5-
  const [FormData, setFormData] = useState({
    name: "",
    phone: "",
    idNo: "",
  });
  const [showAddIdentityCard, setShowAddIdentityCard] = useState(false);
  const [bankCard, setBankCard] = useState([]);

  // 获取银行卡列表
  useEffect(() => {
    Taro.showLoading();

    querybkBankCard().then((res) => {
      console.log(res, "queryBkAgreement");
      setBankCard(res?.records || []);
      Taro.hideLoading();
    });
  }, []);

  useEffect(() => {
    if (user?.userInfo?.person?.personId) {
      const person = user.userInfo.person;
      setUserRole(
        person.personType === ROLE_CODE.CHANNEL_AGENT
          ? 2
          : person.personType === ROLE_CODE.CONSULTANT
          ? 3
          : person.personType === ROLE_CODE.MARKETING
          ? 4
          : 1
      );
    }
  }, [user]);

  useEffect(() => {
    setUserInfo(user?.userInfo?.person);

    setFormData({
      name: user?.userInfo?.person.name,
      phone: user?.userInfo?.person.phone,
      idNo: user?.userInfo?.person.idNo,
    });
  }, [user]);

  const Save = () => {
    fetch({
      url: `${API_BIND_BROKER}`,
      method: "put",
      payload: { ...FormData, bankCardList: bankCard, recommendAgent  },
    }).then(() => {
      Taro.showToast({
        title: "修改成功",
        icon: "none",
      });
      dispatch({
        type: UPDATE_USER_INFO,
        payload: {
          name: FormData.name,
          phone: FormData.phone,
          idNo: FormData.idNo,
        },
      });
      Taro.navigateBack({ delta: 1 });
      // login({ path: '', scene: '' })
    });
  };

  const hangDeleteBankCard = (e) => {
    setBankCard((data) => {
      return data.filter((x) => x.cardNo !== e.cardNo);
    });
  };

  const handDefaultChang = (e) => {
    setBankCard((data) => {
      return data.map(x=>{
        if(x.cardNo===e.cardNo){
          return {
            ...x,
            isDefault:1
          }
        }else{
          return {
            ...x,
            isDefault:0
          }
        }
     
      });
    });
  };
  
  const handAddBankCard = (e) => {
    if (bankCard.find((x) => x.cardNo === e.cardNo)) {
      Taro.showToast({
        title: "存在相同银行卡",
        icon: "none",
        duration: 2000,
      });
    } else {
      setShowAddIdentityCard(false);
      setBankCard((data) => {
        const isDefault = data?.length ===0?1:0
        return [...data, {...e,isDefault}];
      });
    }
  };

  const FormChange = (key, e) => {
    let Data = { ...FormData };
    Data[key] = e.detail.value;
    setFormData(Data);
  };


  console.log(UserInfo, "UserInfo");
  return (
    <view className="Page UserInfo">
      <ScrollView scroll-y>
        <view className="PageContent">
          <text>头像</text>
          <view className="FormLine flex-h">
            <view className="flex-item">
              <view className="Icon">
                <Image
                  mode="aspectFill"
                  src={getImgURL(UserInfo.userPhoto || UserInfo.avatarurl)}
                ></Image>
              </view>
            </view>
            {/* <text className='iconfont icon-jiantouright'></text> */}
          </view>

          <text>用户名</text>
          <view className="FormLine flex-h">
            <view className="flex-item">
              <Input
                placeholder="请输入用户名"
                value={FormData.name}
                onInput={FormChange.bind(this, "name")}
              ></Input>
            </view>
          </view>

          <text>手机号码</text>
          <view className="FormLine flex-h">
            <view className="flex-item">
              <Input
                placeholder="请输入手机号码"
                value={FormData.phone}
                onInput={FormChange.bind(this, "phone")}
              ></Input>
            </view>
          </view>

          <text>证件号码</text>
          <view className="FormLine flex-h">
            <view className="flex-item">
              <Input
                placeholder="请输入证件号码"
                value={FormData.idNo}
                onInput={FormChange.bind(this, "idNo")}
              ></Input>
            </view>
          </view>

          <CardItem
            // title="银行卡号"
            bankCard={bankCard}
            onDefaultChang={handDefaultChang}
            onDelete={hangDeleteBankCard}
            addCard={() => setShowAddIdentityCard(true)}
          ></CardItem>
          {/* <text>证件号码</text>
          <view className='FormLine flex-h'>
            <view className='flex-item'>
              <Input placeholder='请输入手机号码' value={FormData.phone} onInput={FormChange.bind(this, 'phone')}></Input>
            </view>
          </view> */}
        </view>

        <view className="Btn">
          <text onClick={Save}>保存</text>
        </view>
      </ScrollView>

      {showAddIdentityCard && (
        <AddBankCard
          onChange={(e) => handAddBankCard(e)}
          onChanel={() => setShowAddIdentityCard(false)}
        ></AddBankCard>
      )}
    </view>
  );
});
